@@ -4,7 +4,7 @@
 modname = 'brainomics'
 distname = 'cubicweb-brainomics'
 
-numversion = (0, 11, 0)
+numversion = (0, 11, 3)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -17,13 +17,13 @@ __depends__ =  {'cubicweb': '>= 3.18.5',
                 'cubicweb-questionnaire': '>= 0.7.0',
                 'cubicweb-neuroimaging': '>= 0.7.0',
                 'cubicweb-genomics': '>= 0.10.0',
-                'cubicweb-medicalexp': '>= 0.12.0',
+                'cubicweb-medicalexp': '>= 0.12.2',
                 'cubicweb-card': None,
                 'cubicweb-bootstrap': '>= 0.6.0',
                 'cubicweb-squareui': '>= 0.3.5',
                 'cubicweb-comment': None,
                 'cubicweb-jqplot': None,
-                'cubicweb-clinipath': '>= 0.2.0',
+                'cubicweb-clinipath': '>= 0.2.1',
                 }
 __recommends__ = {'cubicweb-vtimeline': '>= 0.5.0'}
 
@@ -47,7 +47,10 @@ data_files = [
 # check for possible extended cube layout
 for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'wdoc',
               'i18n', 'migration', 'importers',
-              'data/bootstrap', 'data/bootstrap/css', 'data/bootstrap/img', 'data/images', 'data/img',):
+              'data/bootstrap', 'data/bootstrap/css', 'data/bootstrap/img',
+              'data/images', 'data/img',
+              'data/SlickGrid', 'data/Slickgrid/controls',
+              'data/SlickGrid/images', 'data/SlickGrid/plugins'):
     if isdir(dname):
         data_files.append([join(THIS_CUBE_DIR, dname), listdir(dname)])
 # Note: here, you'll need to add subdirectories if you want
