@@ -22,6 +22,9 @@ import os.path as osp
 from cubicweb.view import EntityAdapter
 from cubicweb.predicates import is_instance
 
+from cubes.medicalexp.entities import ScoreValue
+
+
 MEASURES = ['GenericMeasure', 'Scan', 'GenericTestRun', 'QuestionnaireRun', 'GenomicMeasure']
 
 
@@ -45,3 +48,15 @@ class DiagnosticICalendarableAdapter(EntityAdapter):
     @property
     def start(self):
         return self.entity.diagnostic_date
+
+
+class ScoreValue(ScoreValue):
+
+    @property
+    def subject(self):
+        if self.reverse_related_infos:
+            return self.reverse_related_infos[0]
+        if self.measure:
+            return self.measure[0].concerns[0]
+        if self.score_of_sample:
+            return self.score_of_sample[0].reverse_related_samples[0]
