@@ -34,13 +34,18 @@ class BrainomicsAbstractOutOfContextView(EntityView):
             icon = u''
         self.w(u'<div class="col-md-2"><p class="text-center">%s</p></div>' % icon)
 
+    def additional_infos(self, entity):
+        pass
+
     def cell_call(self, row, col):
         w = self.w
         entity = self.cw_rset.get_entity(row, col)
         w(u'<div class="ooview"><div class="well"><div class="row">')
         self.add_icon()
         w(u'<div class="col-md-10"><h4>%s</h4></div>' % entity.view('incontext'))
-        w(u'</div></div></div>')
+        w(u'</div>')
+        self.additional_infos(entity)
+        w(u'</div></div>')
 
 
 class StudyOutOfContextView(BrainomicsAbstractOutOfContextView):
@@ -169,3 +174,13 @@ class BiologicalSamplesOutOfContextView(BrainomicsAbstractOutOfContextView):
                                                                              'CellCulture',
                                                                              'BloodSample')
     icon = 'asterisk'
+
+
+class TherapyEvaluationOutOfContextView(BrainomicsAbstractOutOfContextView):
+    __select__ = BrainomicsAbstractOutOfContextView.__select__ & is_instance('TherapyEvaluation')
+    icon = 'info-sign'
+
+
+class SurvivalDataOutOfContextView(BrainomicsAbstractOutOfContextView):
+    __select__ = BrainomicsAbstractOutOfContextView.__select__ & is_instance('SurvivalData')
+    icon = 'heart'
