@@ -86,6 +86,7 @@ class AbstractMutationTableView(SlickGridEntityTableView, EntityTableView):
                'reference_base', 'variant_base', 'variant_coverage', 'coverage',
                'reference_id', 'dbsnp', 'locus_version', 'nucl',
                'sift', 'polyphen', 'classification_variant']
+    grid_options = {'enableCellNavigation':True, 'frozenColumn': 0}
 
 
 class MutationTableView(AbstractMutationTableView):
@@ -248,10 +249,9 @@ class TechnicalAnalysisTableView(EntityTableView):
         elif entity.analysis_of_sample:
             return entity.analysis_of_sample[0].view('incontext')
 
-    columns = ['protocols', 'technique_type', 'results', 'conclusion',
+    columns = ['technique_type', 'results', 'conclusion',
                'analysis_date', _('analysis_on')]
-    column_renderers = {'protocols': RelationColRenderer(role='subject', vid='incontext'),
-                        'technique_type': RelationColRenderer(role='subject', vid='incontext'),
+    column_renderers = {'technique_type': RelationColRenderer(role='subject', vid='incontext'),
                         'analysis_on': EntityTableColRenderer(renderfunc=render_analysis_on)
                        }
 
@@ -262,5 +262,5 @@ class TechnicalAnalysisTableView(EntityTableView):
 class BiopsySampleTableView(EntityTableView):
     __select__ = EntityTableView.__select__ & is_instance('BiopsySample')
     __regid__ = 'biopsysample-table-view'
-    layout_id = 'filter_table_layout'
+    layout_id = 'table_layout'
     columns = ['size', 'name', 'code', 'tumoral_cell_percent', 'necrosis_percent']
